.. _minister:


.. raw:: html

    <br>


.. title:: Gif toedienende artsen de cel in !!


.. raw:: html

    <center>

minister-president
==================

.. raw:: html

    </center>
    <br>


Geachte Minister-President,

|  omdat de :ref:`Koningin <beuker>` gemeld heeft dat ze vanwege ministeriele verantwoordelijkheden geen tussenkomst kan bieden, wend ik mij tot u.

Ik ben Bart Thate, een 50 jaar oude schizofrenie patient. 

Op 20 Oktober 2012 heb ik na correspondentie met de :ref:`Koningin <beuker>` een :ref:`klacht <greffe>` tegen de Nederland ingedient (Thate tegen Nederland 69389/12). 
De klacht betrof het falen van de :ref:`(F)ACT <fact>` methodiek, de methode die GGZ Nederland gebruikt om vorm te geven aan de wetten die gedwongen behandeling in Nederland mogelijk maken.
De :ref:`uitspraak <uitspraak>` is niet-ontvankelijk.

Het is voor mij niet mogelijk gebleken om aangifte te doen van mishandeling als de psychiater zijn patient met gif mishandelt:

* De IGZ treft geen structurele :ref:`onzorgvuldigheid <igz>` in de afhandeling van klachten bij GGZ-NHN aan.
* De :ref:`Hoge Raad <hogeraad>` concludeert dat het geen verantwoordelijkheid heeft en verwijst naar het Openbaar Ministerie, dat niet reageert.
* Daarna heb ik het Europeese Hof voor de Rechten van de Mens aangeschreven om een :ref:`klacht <greffe>` tegen Nederland in te dienen. 
* Pas na een gang langs het EVRM reageert Het :ref:`Openbaar Ministerie <om>` wel en verwijst naar de IGZ, die de klacht melding al heeft afgesloten. 

Het ontbreekt de GGZ patient aan een daadwerkelijke remedie om een einde te kunnen maken aan de mishandeling die een arts pleegt als hij gif toedient.

Er is bewijs dat antipsychotica gif zijn:

* haloperiodol (haldol) - https://echa.europa.eu/substance-information/-/substanceinfo/100.000.142
* clozapine (leponex) - https://echa.europa.eu/substance-information/-/substanceinfo/100.024.831
* olanzapine (zyprexa) - https://echa.europa.eu/substance-information/-/substanceinfo/100.125.320
* aripriprazole (abilify) https://echa.europa.eu/substance-information/-/substanceinfo/100.112.532

Gif toedienen is dodelijk, doordat de patient potentieel dodelijke aandoeninngen kan op doen.
Bijvoorbeeld clozapine (geadviseerd in de zorgstandaard Psychose) kent de volgende potentieel dodelijke aandoeningen, zie (1):

* neutropenia (tekort witte bloedcellen)
* myocarditis (ontsteking hartspier)
* cardiomyopathy (ook hartspier)
* Hypotension (lage bloeddruk)
* bradycardia (trage hartslag)
* syncope (flauwvallen)
* cardiac carrest (hartstilstand)
* neuroleptic malignant syndrome (NMS)
* constipation (dikke darm verstopping)
* intestinal obstruction (darm problemen)
* fecal impaction (vastzittend stront)
* paralytic ileus (ook voedsel vastzittend in de darm)

Los van bijwerkingen die dodelijk kunnen zijn, kan dit medicijn ook in dodelijk hoeveelheid worden toegediend.
12,5 mg is als dodelijk genoteerd, standaard OD is 2.5 gram, sommige overleven boven de 4 gram.

Dat het hier gif betreft en niet een onschadelijk medicijn maakt dat men een :ref:`strafbaar feit <strafbaar2>` pleegt.

Elke dag dat het Openbaar Ministerie niet voor vergiftiging vervolgt moeten miljoenen Nederlanders medicijnen nemen van hun arts dat in werkelijkheid gif is.

U bent verantwoordelijk voor de zorg die de meest kwetsbaren hier in Nederland krijgen, u dient daarom te zorgen dat de zorg/verpleging die men ontvangt niet het plegen van strafbare feiten omvat.

U dient ook te zorgen dat de GGZ patient WEL bij de strafrechter terecht kan als de arts gif toedient.

Daarom heb ik u de volgende eisen te stellen:

* gif toedienende artsen door het Openbaar Ministerie laten vervolgen.
* voor de GGZ patient de vervolging doen.

Er van uitgaande dat u mijn eisen inwilligt,

.. raw:: html

    <br><br>

Bart Thate 


p.s.

het ligt niet in mijn vermogen om u via de rechter te dwingen deze eisen in te willigen.

urls:

1) https://www.ncbi.nlm.nih.gov/pmc/articles/PMC3476840/
2) https://drive.google.com/open?id=0BwaFXkZBje4OdnBmS05sQ2dkUEE

